#! /bin/bash

EXECUTABLE_NAME=LanCtrlApp
FILE_PID="/var/run/${EXECUTABLE_NAME}.pid"
PATH_LIB="/usr/lib"
PROGRAM_NAME=pnm
PATH_PROGRAM_INSTALL="/etc/${PROGRAM_NAME}"
PACKAGE_NAME_DEB=pnm-32-libc6.deb
PACKAGE_NAME_RPM=pnm-32-libc6.rpm

function clear_init_scripts()
{
	rm -f /etc/rc2.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	rm -f /etc/rc3.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	rm -f /etc/rc4.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	rm -f /etc/rc5.d/S99${PROGRAM_NAME} > /dev/null 2>&1

	rm -f /etc/rc0.d/K20${PROGRAM_NAME} > /dev/null 2>&1
	rm -f /etc/rc1.d/K20${PROGRAM_NAME} > /dev/null 2>&1
	rm -f /etc/rc6.d/K20${PROGRAM_NAME} > /dev/null 2>&1
}

function forced_clear()
{
	rm -rf ${PATH_PROGRAM_INSTALL} > /dev/null
	
	if [ -f ${PATH_LIB}/libLanCtrlCommon.so ]
	then 
		rm -f ${PATH_LIB}/libLanCtrlCommon.so > /dev/null 2>&1
	fi

	if [ -f ${PATH_LIB}/libLanCtrlHardwareMonitor.so ]
	then 
		rm -f ${PATH_LIB}/libLanCtrlHardwareMonitor.so > /dev/null 2>&1
	fi

	if [ -f ${PATH_LIB}/libLanCtrlOperations.so ]
	then 
		rm -f ${PATH_LIB}/libLanCtrlOperations.so > /dev/null 2>&1
	fi

	if [ -f ${PATH_LIB}/libLanCtrlScheduler.so ]
	then 
		rm -f ${PATH_LIB}/libLanCtrlScheduler.so > /dev/null 2>&1
	fi

	if [ -f /etc/init.d/${PROGRAM_NAME} ]
	then
		rm -f /etc/init.d/${PROGRAM_NAME} > /dev/null 2>&1
	fi

	if [ -f ${FILE_PID} ]
	then 
		rm -f ${FILE_PID} > /dev/null
	fi

	clear_init_scripts
}

function setup_init_scripts()
{
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc2.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc3.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc4.d/S99${PROGRAM_NAME} > /dev/null 2>&1
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc5.d/S99${PROGRAM_NAME} > /dev/null 2>&1

	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc0.d/K20${PROGRAM_NAME} > /dev/null 2>&1
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc1.d/K20${PROGRAM_NAME} > /dev/null 2>&1
	ln -s /etc/init.d/${PROGRAM_NAME} /etc/rc6.d/K20${PROGRAM_NAME} > /dev/null 2>&1
}

function do_install()
{
	if [ "$1" == "deb" ]
	then
		dpkg -i ${PACKAGE_NAME_DEB}

		if [ $? -ne 0 ]
		then
			echo "An error occurred during setup.";
			dpkg --purge ${PROGRAM_NAME}
			forced_clear
			exit 1;
		fi
	elif [ "$1" == "rpm" ]
	then
		rpm -i ${PACKAGE_NAME_RPM} --force

		if [ $? -ne 0 ]
		then
			echo "An error occurred during setup.";
			rpm -e ${PROGRAM_NAME}
			forced_clear
			exit 1;
		fi
	else
		echo "Invalid installation method. Please use the argument 'deb' or 'rpm'."
		exit 1
	fi



	setup_init_scripts

	${PATH_PROGRAM_INSTALL}/LanCtrlInstaller
		
	if [ $? -ne 0 ]
	then
		echo "Error while running the installer."
		dpkg --purge ${PROGRAM_NAME}
		forced_clear
		exit 1
	fi

	${PATH_PROGRAM_INSTALL}/LanCtrlApp &

	return 0
}

function stop()
{
	if [ -f $FILE_PID ]
	then
		pid=`more $FILE_PID`
		kill $pid > /dev/null 2>&1
		sleep 5

		pid=`pgrep -x $EXECUTABLE_NAME`

		if [ "$pid" != "" ]
		then
			killall -9 $EXECUTABLE_NAME > /dev/null 2>&1

			if [ -f $FILE_PID ]
			then
				rm $FILE_PID > /dev/null 2>&1
			fi
		fi
	else
		pid=`pgrep -x $EXECUTABLE_NAME`

		if [ "$pid" != "" ]
		then
			killall -2 $pid > /dev/null 2>&1
			sleep 5

			pid=`pgrep -x $EXECUTABLE_NAME`
		
			if [ "$pid" != "" ]
			then
				killall -9 $EXECUTABLE_NAME > /dev/null 2>&1

				if [ -f $FILE_PID ]
				then
					rm $FILE_PID > /dev/null 2>&1
				fi
			fi
		fi
	fi
}

function do_remove()
{
	if [ -d ${PATH_PROGRAM_INSTALL}/Packages ]
	then
		rm -r ${PATH_PROGRAM_INSTALL}/Packages > /dev/null 2>&1
	fi

	if [ "$1" == "deb" ]
	then
		dpkg --purge ${PROGRAM_NAME}
	elif [ "$1" == "rpm" ]
	then
		rpm -e ${PROGRAM_NAME}
	else
		echo "Invalid removal method. Please use the argument 'deb' or 'rpm'."
		exit 1
	fi

	if [ $? -ne 0 ]
	then
		echo "An error occurred while removing the application, will forcefully remove its files.";
		forced_clear
	fi

	clear_init_scripts
}

if [ $UID -ne 0 ]
then
	echo "Please run this script as administrator."
	exit 1;
fi

case $1 in
	install)
		stop
		do_install $2
        ;;

	remove)
		stop
		do_remove $2
	;;

	reinstall)
		stop
		do_remove $2
		do_install $2
	;;

	*)
		echo "Usage: setup.sh {install {deb|rpm}|remove|reinstall}"
	;;
esac

